<?php
/*
 * The main plugin class, holds everything our plugin does,
 * initialized right after declaration
 */
class SHWCPZ_ADMIN {
	// properties	
	private $plugin_options_key = 'shwcp_options';
	public $wcpz_events = array();

	// methods
	function __construct() {
		// Events
		$this->wcpz_events = array(
			'none'                => "-- " . __('Choose', 'shwcpz') . " --",
        	'shwcpz-add-entry'    => __('Entry Created', 'shwcpz'),
        	'shwcpz-update-entry' => __('Entry Updated', 'shwcpz'),
        	'shwcpz-del-entry'    => __('Entry Deleted', 'shwcpz'),
			// Preliminary Zapier just use the ones above
        	//'shwcpz-addnote'      => __('Note Added', 'shwcpz'),
        	//'shwcpz-updatenote'   => __('Note Updated', 'shwcpz'),
        	//'shwcpz-delnote'      => __('Note Deleted', 'shwcpz'),
        	//'shwcpz-photoentry'   => __('Photo Updated', 'shwcpz'),
        	//'shwcpz-addfiles'     => __('File Added', 'shwcpz'),
        	//'shwcpz-delfiles'     => __('File Deleted', 'shwcpz'),
    	);
		// submenus
		add_action('admin_menu', array(&$this, 'add_zapier_submenu' ) );

        // Callback Ajax Backend ajax
        require_once(SHWCPZ_ROOT_PATH . '/includes/class-wcpz-ajax.php');
        $wcpz_ajax = new wcpz_ajax();
        add_action( 'wp_ajax_ajax-wcpzbackend', array($wcpz_ajax, 'myajax_wcpzbackend_callback'));
	}

	/*
	 * Zapier Submenu option page
	 */
	function add_zapier_submenu() {
		$add_zapier = add_submenu_page( $this->plugin_options_key, __('Zapier Extension', 'shwcp'), __('Zapier Extension', 'shwcp'),
			'manage_options', 'shwcpz_add_zapier', array(&$this, 'shwcpz_add_zapier'));
		// loaded only in our Contacts menu
        add_action( 'load-' . $add_zapier, array($this, 'load_zapier_scripts') );
	}

	/*
     * Submenu add Zapier page
     */
	function shwcpz_add_zapier() {
		$zapier = get_option('shwcp_zapier');
		if (!$zapier) {
			add_option('shwcp_zapier');
		}
		//$zapier_settings = array();
		//if (!empty($zapier)) {
		//	$zapier_settings = unserialize($zapier);
		//}

		$title = __('WP Contacts Zapier Integration', 'shwcpz');
        $placeholder = 'Activation code';
        $label = __('Activation Code', 'shwcpz');
		$desc_label = __('Description', 'shwcpz');
		$dropdown_label = __('Event To Send', 'shwcpz');
        $save = __('Save Code', 'shwcpz');
		$valid_text = __('Code is valid and has been saved.', 'shwcpz');
		$invalid_text = __('The code provided is either invalid or being used on anther site.', 'shwcpz');
		$release = __('Release Code', 'shwcpz');
		$saved = ' style="display:none;" ';
        $submitted = isset($_GET['submitted']) ? intval($_GET['submitted']) : '';
        $description = __('You are using the WP Contacts Zapier extension with version number ', 'shwcpz') . '<b>' . SHWCPZ_PLUGIN_VERSION . '</b>';
		$code_usage =__('Please note that this activation code is good for one website at a time.  If you want to transfer to another site, release it from this site and add it to the other.', 'shwcpz');
        $steps = __('Steps to configure Zapier', 'shwcpz');
        $step1 = __('Insert your activation code and save, make sure you are using an ssl certificate (https) on this site and create a new zap at zapier.com.', 'shwcpz');
        $step2 = __('If you want WP Contacts to notify another application use one of our triggers.  If you want something done with WP Contacts from another application use one of our actions.', 'shwcpz');
        $step3 = __("Have fun, that's it!", 'shwcpz');
		$zapier_logo = SHWCPZ_ROOT_URL . '/assets/img/Zapier_logo.png';
		$wpc_logo = SHWCPZ_ROOT_URL . '/assets/img/wp-contacts-square-lg.png';
		$license = get_option('shwcpz_license');
		$license = unserialize($license);
		$activation = isset($license['activation']) ? $license['activation'] : '';

        echo <<<EOC
            <div class="wrap"><div id="icon-tools" class="icon32"></div>
                <h2>$title</h2>
                <p>$description</p>
            </div>
            <hr />
			<a href="https://www.zapier.com" target="_blank"><img class="zapier-logo" src="$zapier_logo" /></a>

            <h4>$steps</h4>
            <div class="shwcp-create-steps">
              <ol>
                <li>$step1</li>
                <li>$step2</li>
                <li>$step3</li>
              </ol>
			<hr />
			<label for="shwcpz-activation">$label : </label>
            <input class="shwcpz-activation" type="text" placeholder="$placeholder" value="$activation" />
			<button class="button-primary shwcpz-save">$save</button>
			<div class="shwcpz-saved-cont"><div class="shwcpz-saved" $saved><h3> </h3></div></div>
			<div style="clear:both;"></div>
			<div class="code-usage"><i>$code_usage</i></div>
			<p><button class="button-secondary shwcpz-release">$release</button></p>
			<div style="clear:both;"></div>
			<img class="wpcontacts-logo" src="$wpc_logo" style="height:180px;width:180px;"/>
            </div>
            <hr />
			<div class="valid-code" style="display:none;">$valid_text</div>
			<div class="invalid-code" style="display:none;">$invalid_text</div>
EOC;
	}
	/* Only called on our Zapier settings page */
	function load_zapier_scripts() {
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_zapier_scripts' ), 10, 1 );
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_zapier_styles' ), 10, 1 );
	}

	/**
     * Load admin Zapier CSS.
     * @access public
     * @since 2.0.0
     * @return void
     */
    public function admin_enqueue_zapier_styles ( $hook = '' ) {
		wp_register_style( 'wcp-zapier', SHWCPZ_ROOT_URL . '/assets/css/admin-zapier.css', array(), SHWCPZ_PLUGIN_VERSION );
        wp_enqueue_style( 'wcp-zapier' );

    } // End admin_enqueue_zapier_styles

	/**
     * Load admin Javascript for zapier page
     * @access public
     * @since 2.0.0
     * @return void
     */
    public function admin_enqueue_zapier_scripts ($hook = '' ) {
		wp_enqueue_script('jquery-effects-core');
		wp_enqueue_script('jquery-effects-highlight');
        wp_register_script( 'wcp-zapier',
        SHWCPZ_ROOT_URL . '/assets/js/admin-zapier.js', array( 'jquery-effects-core' ), SHWCPZ_PLUGIN_VERSION, true );
        wp_enqueue_script( 'wcp-zapier' );
        wp_localize_script( 'wcp-zapier', 'WCP_Ajax_Zapier_Admin', array(
            'ajaxurl' => admin_url('admin-ajax.php'),
            'nextNonce' => wp_create_nonce( 'myajax-next-nonce' )
        ));
    } // End admin_enqueue_zapier
};

// Initialize the plugin
add_action( 'plugins_loaded', function() {$settings_api_tabs_shwcp = new SHWCPZ_ADMIN;} );
