<?php
/**
 * Class wcpz_hooks
 * WP API Integration for Zapier hooks
 */

	class wcpz_hooks {
		// properties
		protected $zapier_settings = array();
		protected $zapier_urls = array();

		// methods

		/**
		 * 
		 * @access public
		 * @since 1.0.1
		**/
		public function __construct() {
			$zapier = get_option('shwcp_zapier');
        	$this->zapier_settings = array();
        	if (!empty($zapier)) {
            	$this->zapier_settings = unserialize($zapier);
        	}

			// execute actions
			if (!empty($this->zapier_settings)) {
				$temp_urls = isset($this->zapier_settings['zapier_targets']) ? $this->zapier_settings['zapier_targets'] : array();
				foreach ($temp_urls as $k => $v) {  // cleanup
					if ($v['target_url'] != '') {
						$zapier_targets[] = array(
							'target_url' => $v['target_url'],
							'event'      => $v['event'],
							'db'         => $v['db']
						);
					}
					$this->zapier_urls = $zapier_targets;
				}
				// Add Entry
				add_action('wcp_add_entry_action', array($this, 'add_entry_hook'), 10, 2);
				// Update Entry
                add_action('wcp_update_entry_action', array($this, 'update_entry_hook'), 10, 2);
				// Delete Entry
                add_action('wcp_del_entry_action', array($this, 'del_entry_hook'), 10, 2);
				/*
				 * Disabled until after global and we choose what we need
				 * keep in mind settings have changed, so these will have to be adjusted like the enabled ones
				// Set Entry Photo
                add_action('wcp_photo_entry_action', array($this, 'photo_entry_hook'), 10, 3);
				// Add Entry Files
                add_action('wcp_addfiles_entry_action', array($this, 'addfiles_entry_hook'), 10, 3);
				// Delete Entry Files
                add_action('wcp_delfiles_entry_action', array($this, 'delfiles_entry_hook'), 10, 3);
				// Add Note
                add_action('wcp_addnote_entry_action', array($this, 'addnote_entry_hook'), 10, 4);
				// Update Note
                add_action('wcp_updatenote_entry_action', array($this, 'updatenote_entry_hook'), 10, 4);
				// Delete Note
                add_action('wcp_delnote_entry_action', array($this, 'delnote_entry_hook'), 10, 4);
				*/
			}
				
		}

		/**
		 * Add Entry Action
		 */
		public function add_entry_hook($fields, $environment) {
			$entry_event = 'add_entry';
			foreach ($this->zapier_urls as $k => $v) {
				$url   = $v['target_url'];
				$event = $v['event'];
				$db    = $v['db'];
				if ($event == $entry_event && $url != '') { // url not empty and event match
					$same_db = $this->get_current_db($db, $environment['db_name']);					
					if ($same_db) { // continue
						$response = wp_remote_post($url, 
							array(
								'headers' => array('Content-Type' => 'application/json; charset=utf-8'),
								'method' => 'POST',
								'body' => json_encode(array(
									'action' => $entry_event,
									'fields' => $fields,
									'db' => $environment['db_name']
									//'environment' => $environment,
								))
							)
						);
						if ($response['response']['code'] == 410) {   // Zapier says it no longer exists
							$this->remove_hook($url, $event);
						}
					}
				}
			}
		}

		/**
		 * Update Entry Action
		 */
		public function update_entry_hook($fields, $environment) {
			$entry_event = 'update_entry';
			foreach ($this->zapier_urls as $k => $v) {
				$url   = $v['target_url'];
                $event = $v['event'];
                $db    = $v['db'];
                if ($event == $entry_event && $url != '') { // url not empty and event match
					$same_db = $this->get_current_db($db, $environment['db_name']);
                    if ($same_db) { // continue
            			$response = wp_remote_post($url, 
                			array(
								'headers' => array('Content-Type' => 'application/json; charset=utf-8'),
                    			'method' => 'POST',
                    			'body' => json_encode(array(
                        			'action' => $entry_event,
                        			'fields' => $fields,
									'db' => $environment['db_name']
                        			//'environment' => $environment,
                    			))
                			)
            			);
						if ($response['response']['code'] == 410) {   // Zapier says it no longer exists
                        	$this->remove_hook($url, $event);
                    	}
					}
				}
			}
		}

		/**
		 * Delete Entry Action
		 */
		public function del_entry_hook($fields, $environment) {
			$entry_event = 'del_entry';
			foreach ($this->zapier_urls as $k => $v) {
				$url   = $v['target_url'];
                $event = $v['event'];
                $db    = $v['db'];
                if ($event == $entry_event && $url != '') { // url not empty and event match
					$same_db = $this->get_current_db($db, $environment['db_name']);
                    if ($same_db) { // continue
            			$response = wp_remote_post($url, 
                			array(
								'headers' => array('Content-Type' => 'application/json; charset=utf-8'),
                    			'method' => 'POST',
                    			'body' => json_encode(array(
                        			'action' => $entry_event,
                        			'fields' => $fields,
									'db'     => $environment['db_name']
                        			//'environment' => $environment,
                    			))
                			)
            			);
						if ($response['response']['code'] == 410) {   // Zapier says it no longer exists
                        	$this->remove_hook($url, $event);
                    	}
					}
				}
			}
		}

		/**
		 * Entry Photo Action
		 */
		public function photo_entry_hook($lead_id, $new_file_url, $environment) {
			$entry_event = 'shwcpz-photoentry';
			$action = 'add_photo_entry';
			foreach ($this->zapier_urls as $k => $v) {
                $url = $v['url'];
				$event = $v['event'];
                if ($event == $entry_event && $url != '') { // url not empty and event match
            		$response = wp_remote_post($url, 
                		array(
							'headers' => array('Content-Type' => 'application/json; charset=utf-8'),
                    		'method' => 'POST',
                    		'body' => json_encode(array(
                        		'action' => $action,
                        		'lead_id' => $lead_id,
								'new_file_url' => $new_file_url,
								'db' => $environment['db_name']
                        		//'environment' => $environment,
                    		))
                		)
            		);
				}
			}
		}

		/**
		 * Add Entry Files Action
		 */
		public function addfiles_entry_hook($lead_id, $file_data, $environment) {
			$entry_event = 'shwcpz-addfiles';
			$action = 'add_files_entry';
			foreach ($this->zapier_urls as $k => $v) {
                $url = $v['url'];
				$event = $v['event'];
                if ($event == $entry_event && $url != '') { // url not empty and event match
            		$response = wp_remote_post($url,
                		array(
							'headers' => array('Content-Type' => 'application/json; charset=utf-8'),
                    		'method' => 'POST',
                    		'body' => json_encode(array(
                        		'action' => $action,
                        		'lead_id' => $lead_id,
                        		'file_data' => $file_data,
								'db' => $environment['db_name']
                        		//'environment' => $environment,
                    		))
                		)
            		);
				}
			}
		}

		/**
		 * Delete Entry Files Action
		 */
		public function delfiles_entry_hook($lead_id, $file_data, $environment) {
			$entry_event = 'shwcpz-delfiles';
			$action = 'delete_files_entry';
			foreach ($this->zapier_urls as $k => $v) {
                $url = $v['url'];
				$event = $v['event'];
                if ($event == $entry_event && $url != '') { // url not empty and event match
            		$response = wp_remote_post($url,
                		array(
							'headers' => array('Content-Type' => 'application/json; charset=utf-8'),
                    		'method' => 'POST',
                    		'body' => json_encode(array(
                        		'action' => $action,
                        		'lead_id' => $lead_id,
                        		'file_data' => $file_data,
								'db' => $environment['db_name']
                        		//'environment' => $environment,
                    		))
                		)
            		);
				}
			}
		}
	
		/**
		 * Add Entry Note Action
		 */
		public function addnote_entry_hook($lead_id, $note, $note_id, $environment) {
			$entry_event = 'shwcpz-addnote';
			$action = 'add_note';
			foreach ($this->zapier_urls as $k => $v) {
                $url = $v['url'];
				$event = $v['event'];
                if ($event == $entry_event && $url != '') { // url not empty and event match
            		$response = wp_remote_post($url,
                		array(
							'headers' => array('Content-Type' => 'application/json; charset=utf-8'),
                    		'method' => 'POST',
                    		'body' => json_encode(array(
                        		'action' => $action,
                        		'lead_id' => $lead_id,
                        		'note' => $note,
								'note_id' => $note_id,
								'db' => $environment['db_name']
                        		//'environment' => $environment,
                    		))
                		)
            		);
				}
			}
		}

		/**
		 * Update Entry Note Action
		 */
		public function updatenote_entry_hook($lead_id, $note, $note_id, $environment) {
			$entry_event = 'shwcpz-updatenote';
			$action = 'update_note';
			foreach ($this->zapier_urls as $k => $v) {
                $url = $v['url'];
				$event = $v['event'];
                if ($event == $entry_event && $url != '') { // url not empty and event match
            		$response = wp_remote_post($url,
                		array(
							'headers' => array('Content-Type' => 'application/json; charset=utf-8'),
                    		'method' => 'POST',
                    		'body' => json_encode(array(
                        		'action' => $action,
                        		'lead_id' => $lead_id,
                        		'note' => $note,
                        		'note_id' => $note_id,
								'db' => $environment['db_name']
                        		//'environment' => $environment,
                    		))
                		)
            		);
				}
			}
		}

		/**
		 * Delete Entry Note Action
		 */
		public function delnote_entry_hook($lead_id, $note, $note_id, $environment) {
			$entry_event = 'shwcpz-delnote';
			$action = 'delete_note';
			foreach ($this->zapier_urls as $k => $v) {
                $url = $v['url'];
				$event = $v['event'];
                if ($event == $entry_event && $url != '') { // url not empty and event match
            		$response = wp_remote_post($url,
                		array(
							'headers' => array('Content-Type' => 'application/json; charset=utf-8'),
                    		'method' => 'POST',
                    		'body' => json_encode(array(
                        		'action' => $action,
                        		'lead_id' => $lead_id,
                        		'note' => $note,
                        		'note_id' => $note_id,
								'db' => $environment['db_name']
                        		//'environment' => $environment,
                    		))
                		)
            		);
				}
			}
		}


		/********************************** END Hooks *******************************************/

        /**
         * Dynamic DB name selection for comparison to fire hooks on database name matches
		 * and if db is empty will fire on default only
         *
         * @param string $db_name single db lookup
         *
         * return string or array depending on choice
         */
        public function get_current_db($db_set, $db_current) {
			$default_settings = 'shwcp_main_settings';
            if ($db_set) {  // check if it matches
				if ($db_set == $db_current) {   // matches, no further action
					return true;
				}
            } else {  // database is not set, so just uses default
				$default = get_option($default_settings);
				$default_name = $default['database_name'];
				if ($default_name == $db_current) {
					return true;
				}	
            }
			return false; // doesn't match for current hook firing
        }


		/**
		 * Remove Hook on 410 response from Zapier
		 */
		public function remove_hook($url, $event) {
			$save_targets = array();
			foreach ($this->zapier_urls as $k => $v) {
				if ($v['target_url'] == $url && $v['event'] == $event) { 
					// skip
				} else {
                    $save_targets[$k] = $v;
                }
            }
            $new_targets = array(
                'zapier_targets' => $save_targets
            );
            $new_options = serialize($new_targets);
            update_option('shwcp_zapier', $new_options);
		}

		/**
		 * Currently not used
		 * Check if the value is a mysql date string
		 */
		public function validate_date($date, $format = 'Y-m-d H:i:s') {
    		$d = DateTime::createFromFormat($format, $date);
    		return $d && $d->format($format) == $date;
		}

		/**
		 * Currently not used
		 * Convert mysql datetime to ISO8601 format for Zapier
		 */
		public function convert_iso($date) {
			$datetime = new DateTime($date);
			return $datetime->format(DateTime::ATOM); // Updated ISO8601
		}

	} // end class

