<?php
/*
Plugin Name: WP Contacts - Zapier Extension
Plugin URI: http://www.scripthat.com
Description: Extends WP Contacts for Zapier integration (www.zapier.com).  Once enabled, settings are located in Main WP Contacts menu.
Version: 1.0.9
Author: ScriptHat
Author URI: http://www.scripthat.com
 */
if(defined('SHWCPZ_PLUGIN_VERSION') ) {
    die('ERROR: It looks like you already have one instance of WP Contacts - Zapier installed. WordPress cannot activate and handle two instances at the same time, you need to remove the old one first.');
}

// Constants
define('SHWCPZ', true);
define('SHWCPZ_ROOT_FILE', __FILE__);
define('SHWCPZ_ROOT_PATH', dirname(__FILE__));
define('SHWCPZ_ROOT_URL', plugins_url('', __FILE__));
define('SHWCPZ_PLUGIN_VERSION', '1.0.9');
define('SHWCPZ_PLUGIN_SLUG', basename(dirname(__FILE__)));
define('SHWCPZ_PLUGIN_BASE', plugin_basename(__FILE__));


/*
 * Make sure  WP Contacts is enabled and at the necessary version
 */
function shwcpz_init($license) {
	if ( defined('SHWCP_PLUGIN_VERSION') && version_compare(SHWCP_PLUGIN_VERSION, '3.0.0') >= 0 ) {
		shwcpz_run($license);
	} else {
		function shwcpz_admin_notice__error() {
        	$class = 'notice notice-error';
        	$message = __( 'WP Contacts needs to be active and running version 3.0 or above in order'
					 . ' for the WP Contacts Zapier extension to function.', 'shwcpz' );
        	printf( '<div class="%1$s"><p>%2$s</p></div>', $class, $message );
    	}
    	add_action( 'admin_notices', 'shwcpz_admin_notice__error' );
	}

	if (!$license) {
		function shwcpz_admin_notice__nolicense() {
		$class = 'notice notice-error';
		$message = __( 'You need to enter a valid activation code for the WP Contacts Zapier extension in order to use it and get updates.  You should have received your activation code when purchasing the extension and need to enter that under WP Contacts -> Zapier Extension in the admin menu.', 'shwcpz' );
    	printf( '<div class="%1$s"><p>%2$s</p></div>', $class, $message );
		}
		add_action( 'admin_notices', 'shwcpz_admin_notice__nolicense' );
	}

}
$shwcpz_license = unserialize(get_option('shwcpz_license'));
$license = false;
if ($shwcpz_license && $shwcpz_license['valid'] == 'true') {
	$license = true;
}
shwcpz_init($license);

/*
 * After check plugin run main code 
 * WP plugin load order is by default alphebetical so 
 * this extension loads after WP Contacts (shwcp, shwcpz folders)
 */
function shwcpz_run($license) {
	if ($license) {
		// Zapier Hooks
		require_once( SHWCPZ_ROOT_PATH . '/includes/class-wcpz-hooks.php' );
		$wcpz_hooks = new wcpz_hooks;

		/* Zapier Endpoints */
    	require_once SHWCPZ_ROOT_PATH . '/includes/class-wcpz-endpoints.php';
    	$wcpz_endpoints = new wcpz_endpoints;
	}

	// The admin menu
	if ( is_admin() ) {
		require_once( SHWCPZ_ROOT_PATH . '/includes/class-wcpz-admin.php' );
	}

	// Translations
	add_action('init', 'shwcpz_load_textdomain');
	function shwcpz_load_textdomain() {
		load_plugin_textdomain('shwcpz', false, basename( dirname( __FILE__ ) ) . '/lang');
	}

} // end shwcpz_run

// Automatic Updates
if ($shwcpz_license && $shwcpz_license['valid'] == 'true') {
	require_once SHWCPZ_ROOT_PATH . '/includes/plugin-updates/plugin-update-checker.php';
	$update_checker = Puc_v4_Factory::buildUpdateChecker(
	'http://updates.scripthat.com/server/?action=get_metadata&slug=shwcpz',
	__FILE__, //Full path to the main plugin file or functions.php.
	'shwcpz'
	);	

	$update_checker->addQueryArgFilter('shwcpz_updates_additional_queries');
	function shwcpz_updates_additional_queries($queryArgs) {
		$url_parts = parse_url(home_url());	
		$website = $url_parts['host'];
		// Strip the protocol off of the site
		$find = array( 'http://', 'https://' );
		$replace = '';
		$website = str_replace( $find, $replace, $website );
		$license = unserialize(get_option('shwcpz_license'));
    	$queryArgs['license_key'] = $license['activation'];
		$queryArgs['website']     = $website;
    	$queryArgs['market']      = 'selfhosted';
    	return $queryArgs;
	}
}

/*
 * Check for and add Basic Authentication if plugin is not already included, actual code from plugin included in if 
 * check below.
 */
if (!function_exists('json_basic_auth_handler')) {

	function json_basic_auth_handler( $user ) {
    	global $wp_json_basic_auth_error;

    	$wp_json_basic_auth_error = null;

    	// Don't authenticate twice
    	if ( ! empty( $user ) ) {
        	return $user;
    	}

    	// Check that we're trying to authenticate
    	if ( !isset( $_SERVER['PHP_AUTH_USER'] ) ) {
        	return $user;
    	}

    	$username = $_SERVER['PHP_AUTH_USER'];
    	$password = $_SERVER['PHP_AUTH_PW'];

    	/**
     	 * In multi-site, wp_authenticate_spam_check filter is run on authentication. This filter calls
     	 * get_currentuserinfo which in turn calls the determine_current_user filter. This leads to infinite
     	 * recursion and a stack overflow unless the current function is removed from the determine_current_user
     	 * filter during authentication.
     	 */
    	remove_filter( 'determine_current_user', 'json_basic_auth_handler', 20 );

    	$user = wp_authenticate( $username, $password );

    	add_filter( 'determine_current_user', 'json_basic_auth_handler', 20 );

    	if ( is_wp_error( $user ) ) {
        	$wp_json_basic_auth_error = $user;
        	return null;
    	}

    	$wp_json_basic_auth_error = true;

    	return $user->ID;
	}

	function json_basic_auth_error( $error ) {
    	// Passthrough other errors
    	if ( ! empty( $error ) ) {
        	return $error;
    	}

    	global $wp_json_basic_auth_error;

    	return $wp_json_basic_auth_error;
	}

	add_filter( 'determine_current_user', 'json_basic_auth_handler', 20 );
	add_filter( 'json_authentication_errors', 'json_basic_auth_error' );
}

